@@ -207,12 +207,14 @@ class Cpython(PythonBuilder):
         bc = self.setup.build_context
         yield "compilation-info", {
             "compiled-by": compiled_by or "https://pypi.org/project/portable-python/",
-            "data": datetime.datetime.now().strftime("%Y-%M-%d %H:%M"),
+            "data": datetime.datetime.now().strftime("%Y-%m-%d %H:%M"),
             "host-platform": runez.SYS_INFO.platform_info,
             "portable-python-version": runez.get_version(__package__),
             "special-context": bc.isolate_usr_local and bc,
         }
-        yield "additional-info", PPG.config.get_value("manifest", "additional-info")
+        additional = PPG.config.get_value("manifest", "additional-info")
+        if additional:
+            yield "additional-info", additional
 
     def _find_sys_cfg(self):
         if self.config_folder:
